from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Int, Float, Boolean, Directory

Gappa_Examine_Assign_V0_1_0 = CommandToolBuilder(tool="gappa_examine_assign", base_command=["gappa", "examine", "assign"], inputs=[ToolInput(tag="in_j_place_path", input_type=File(optional=True), prefix="--jplace-path", doc=InputDocumentation(doc=":PATH(existing)=[] ... REQUIRED\nList of jplace files or directories to process. For directories, only files with the extension `.jplace[.gz]` are processed.")), ToolInput(tag="in_tax_on_file", input_type=File(optional=True), prefix="--taxon-file", doc=InputDocumentation(doc=":FILE REQUIRED\nFile containing a tab-separated list of reference taxon to taxonomic string assignments.")), ToolInput(tag="in_root_out_group", input_type=File(optional=True), prefix="--root-outgroup", doc=InputDocumentation(doc=":FILE   Root the tree by the outgroup taxa defined in the specified file.")), ToolInput(tag="in_taxonomy", input_type=File(optional=True), prefix="--taxonomy", doc=InputDocumentation(doc=":FILE        EXPERIMENTAL: File containing a tab-separated list defining the taxonomy. If mapping is incomplete (for example if the output taxonomy shall be NCBI, but SILVA was used as the basis in the --taxon-file) a best-effort mapping is attempted.")), ToolInput(tag="in_ranks_string", input_type=String(optional=True), prefix="--ranks-string", doc=InputDocumentation(doc="=superkingdom|phylum|class|order|family|genus|species\nString specifying the rank names, in order, to which the taxonomy adheres. Required when using the CAMI output format. Assignments not adhereing to this constrained will be collapsed to the last valid mapping\nEXAMPLE: superkingdom|phylum|class|order|family|genus|species")), ToolInput(tag="in_sub_tax_o_path", input_type=String(optional=True), prefix="--sub-taxopath", doc=InputDocumentation(doc="Taxopath (example: Eukaryota;Animalia;Chordata) by which the high level summary should be filtered. Doesn't affect intermediate results, and an unfiltered verison will be printed as well.")), ToolInput(tag="in_max_level", input_type=Int(optional=True), prefix="--max-level", doc=InputDocumentation(doc="=0          Maximal level of the taxonomy to be printed. Default is 0, that is, the whole taxonomy is printed. If set to a value about 0, only this many levels are printed. That is, taxonomic levels below the specified one are omitted.")), ToolInput(tag="in_distribution_ratio", input_type=Float(optional=True), prefix="--distribution-ratio", doc=InputDocumentation(doc=":FLOAT in [0 - 1]=-1\nRatio by which LWR is split between annotations if an edge has two possible annotations. Specifies the amount going to the proximal annotation. If not set program will determine the ratio automatically from the 'distal length' specified per placement.")), ToolInput(tag="in_consensus_thresh", input_type=Float(optional=True), prefix="--consensus-thresh", doc=InputDocumentation(doc=":FLOAT in [0 - 1]=1\nFor assignment of taxonomic labels to the reference tree, require this consensus threshold. Example: if set to 0.6, and 60% of an inner node's descendants share a taxonomic path, set that path at the inner node.")), ToolInput(tag="in_resolve_missing_paths", input_type=Boolean(optional=True), prefix="--resolve-missing-paths", doc=InputDocumentation(doc="Should the taxon file be incomplete and leave some taxa without taxopaths, fill in the missing node labels using the closest (in the tree) label.\nIf not specified, those parts of the tree remain unlabelled, and their placements unassigned.")), ToolInput(tag="in_out_dir", input_type=Directory(optional=True), prefix="--out-dir", doc=InputDocumentation(doc="=.            Directory to write files to")), ToolInput(tag="in_file_prefix", input_type=File(optional=True), prefix="--file-prefix", doc=InputDocumentation(doc="File prefix for output files")), ToolInput(tag="in_file_suffix", input_type=File(optional=True), prefix="--file-suffix", doc=InputDocumentation(doc="File suffix for output files")), ToolInput(tag="in_cami", input_type=String(optional=True), prefix="--cami", doc=InputDocumentation(doc=": --taxonomy    EXPERIMENTAL: Print result in the CAMI Taxonomic Profiling Output Format.")), ToolInput(tag="in_sample_id", input_type=File(optional=True), prefix="--sample-id", doc=InputDocumentation(doc="Needs: --cami\nSample-ID string to be used in the CAMI output file")), ToolInput(tag="in_krona", input_type=Boolean(optional=True), prefix="--krona", doc=InputDocumentation(doc="Print result in the Krona text format.")), ToolInput(tag="in_sativa", input_type=Boolean(optional=True), prefix="--sativa", doc=InputDocumentation(doc="Print result as SATIVA would.")), ToolInput(tag="in_per_query_results", input_type=Boolean(optional=True), prefix="--per-query-results", doc=InputDocumentation(doc="Print intermediate / per-query results (per_query.tsv).")), ToolInput(tag="in_best_hit", input_type=Boolean(optional=True), prefix="--best-hit", doc=InputDocumentation(doc="In the per-query results, only print the taxonomic path with the highest LWR.")), ToolInput(tag="in_allow_file_overwriting", input_type=Boolean(optional=True), prefix="--allow-file-overwriting", doc=InputDocumentation(doc="Allow to overwrite existing output files instead of aborting the command.")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Produce more verbose output.")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="=8            Number of threads to use for calculations.")), ToolInput(tag="in_log_file", input_type=File(optional=True), prefix="--log-file", doc=InputDocumentation(doc="Write all output to a log file, in addition to standard output to the terminal."))], outputs=[ToolOutput(tag="out_taxonomy", output_type=File(optional=True), selector=InputSelector(input_to_select="in_taxonomy", type_hint=File()), doc=OutputDocumentation(doc=":FILE        EXPERIMENTAL: File containing a tab-separated list defining the taxonomy. If mapping is incomplete (for example if the output taxonomy shall be NCBI, but SILVA was used as the basis in the --taxon-file) a best-effort mapping is attempted.")), ToolOutput(tag="out_file_prefix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_file_prefix", type_hint=File()), doc=OutputDocumentation(doc="File prefix for output files")), ToolOutput(tag="out_file_suffix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_file_suffix", type_hint=File()), doc=OutputDocumentation(doc="File suffix for output files")), ToolOutput(tag="out_sample_id", output_type=File(optional=True), selector=InputSelector(input_to_select="in_sample_id", type_hint=File()), doc=OutputDocumentation(doc="Needs: --cami\nSample-ID string to be used in the CAMI output file")), ToolOutput(tag="out_log_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_log_file", type_hint=File()), doc=OutputDocumentation(doc="Write all output to a log file, in addition to standard output to the terminal."))], container="quay.io/biocontainers/gappa:0.7.0--he513fc3_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Gappa_Examine_Assign_V0_1_0().translate("wdl")

